@@ -17,6 +17,7 @@ use domain::rdata::A;
 use lru_time_cache::LruCache;
 
 const DEFAULT_CACHE_EXPIRE: Duration = Duration::from_secs(10 * 60);
+const DEFAULT_CACHE_CAPACITY: usize = 1024;
 
 #[cfg(feature = "slings-runtime")]
 use slings::{
@@ -57,8 +58,9 @@ impl Resolver {
             preferred: ServerList::from_conf(&conf, |s| s.transport.is_preferred()),
             stream: ServerList::from_conf(&conf, |s| s.transport.is_stream()),
             options: conf.options,
-            lru_cache: Arc::new(Mutex::new(LruCache::with_expiry_duration(
+            lru_cache: Arc::new(Mutex::new(LruCache::with_expiry_duration_and_capacity(
                 DEFAULT_CACHE_EXPIRE,
+                DEFAULT_CACHE_CAPACITY,
             ))),
         }
     }
@@ -91,17 +93,15 @@ impl Resolver {
             .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
         let answer = self.query((&qname, Rtype::A)).await?;
         let name = answer.canonical_name();
-        let mut records = answer
+        let records = answer
             .answer()
             .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?
             .limit_to::<A>();
 
         let mut ips = vec![];
-        while let Some(res) = records.next() {
-            if let Ok(record) = res {
-                if Some(*record.owner()) == name {
-                    ips.push(record.data().addr().into());
-                }
+        for record in records.flatten() {
+            if Some(*record.owner()) == name {
+                ips.push(record.data().addr().into());
             }
         }
         self.insert_into_cache(host, ips.clone());
@@ -334,7 +334,7 @@ impl ServerInfo {
             let len = u16::from_be_bytes(len_buf) as u64;
             let mut buf = Vec::new();
             sock.take(len).read_to_end(&mut buf).await?;
-            if let Ok(answer) = Message::from_octets(buf.into()) {
+            if let Ok(answer) = Message::from_octets(buf) {
                 if answer.is_answer(&query.as_message()) {
                     return Ok(answer.into());
                 }
@@ -359,7 +359,7 @@ impl ServerInfo {
             let mut buf = vec![0; recv_size];
             let len = sock.recv(&mut buf).await?;
             buf.truncate(len);
-            let answer = match Message::from_octets(buf.into()) {
+            let answer = match Message::from_octets(buf) {
                 Ok(answer) => answer,
                 Err(_) => continue,
             };
